@@ -151,11 +151,13 @@ is_required_spark <- function(x, required_version) {
   UseMethod("is_required_spark")
 }
 
+#' @export
 is_required_spark.spark_connection <- function(x, required_version) {
   version <- spark_version(x)
   version >= required_version
 }
 
+#' @export
 is_required_spark.spark_jobj <- function(x, required_version) {
   sc <- spark_connection(x)
   is_required_spark(sc, required_version)
@@ -685,3 +687,10 @@ cast_double_list <- function(x, allow_null = FALSE) {
 cast_choice <- function(x, choices, error_arg = rlang::caller_arg(x), error_call = rlang::caller_env()) {
   rlang::arg_match(x, choices, error_arg = error_arg, error_call = error_call)
 }
+
+package_version2 <- function(x) {
+  if(inherits(x, "numeric_version")) {
+    x <- as.character(x)
+  }
+  package_version(x)
+}
